@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,6 +22,7 @@
 #include "kdebugsettings_debug.h"
 #include <QFile>
 #include <QFileInfo>
+#include <QRegularExpression>
 
 RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line)
 {
@@ -75,7 +76,7 @@ RenameCategory::List KDebugSettingsUtil::readRenameCategories(const QString &fil
 KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line)
 {
     KdeLoggingCategory category;
-    int pos = line.indexOf(QLatin1Char('#'));
+    const int pos = line.indexOf(QLatin1Char('#'));
     if (pos != -1) {
         line.truncate(pos);
         line = line.simplified();
@@ -90,12 +91,42 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line)
         qCWarning(KDEBUGSETTINGS_LOG) << "No space:" << line << endl;
         return category;
     }
+#if 0
+    //log linux (foo)
 
     const QString logName = line.left(space);
 
     const QString description = line.mid(space).simplified();
+#else
+    QString logName;
+    QString description;
+    QString defaultCategory;
+    static const QRegularExpression regularExpressionUser(QStringLiteral("^([\\w._-]+)\\s*(.*)$"));
+    QRegularExpressionMatch match = regularExpressionUser.match(line);
+    if (match.hasMatch()) {
+        logName = match.captured(1);
+        description = match.captured(2);
+        //qDebug() << " logName"<<logName<<" description " << description << " line " << line;
+    }
+
+    static const QRegularExpression regularExpressionDefaultCategory(QStringLiteral("^(.*)\\s+\\[(DEBUG|INFO|WARNING|CRITICAL)\\]$"));
+    QRegularExpressionMatch match2 = regularExpressionDefaultCategory.match(description);
+    QString defaultCategoryCaptured;
+    if (match.hasMatch()) {
+        const QString descriptionCaptured = match2.captured(1);
+        defaultCategoryCaptured = match2.captured(2);
+        if (!descriptionCaptured.isEmpty() && !defaultCategoryCaptured.isEmpty()) {
+            description = descriptionCaptured;
+            defaultCategory = defaultCategoryCaptured;
+            //qDebug() << " match.captured(1);" << descriptionCaptured;
+            //qDebug() << " match.captured(2);" << defaultCategoryCaptured;
+        }
+    }
+#endif
+
     category.logName = logName;
     category.description = description;
+    category.defaultCategory = defaultCategoryCaptured;
     return category;
 }
 
@@ -115,7 +146,7 @@ KdeLoggingCategory::List KDebugSettingsUtil::readLoggingCategoriesForInserting(c
             const KdeLoggingCategory category = parseLineKdeLoggingCategory(data);
             if (category.isValid()) {
                 bool needToAppend = true;
-                Q_FOREACH (const KdeLoggingCategory &cat, categoriesList) {
+                for (const KdeLoggingCategory &cat : qAsConst(categoriesList)) {
                     if (cat == category) {
                         needToAppend = false;
                         break;
@@ -146,7 +177,7 @@ void KDebugSettingsUtil::readLoggingCategories(const QString &filename, KdeLoggi
             if (category.isValid()) {
                 if (checkCategoryList) {
                     bool needToAppend = true;
-                    Q_FOREACH (const KdeLoggingCategory &cat, categoriesList) {
+                    for (const KdeLoggingCategory &cat : qAsConst(categoriesList)) {
                         if (cat == category) {
                             needToAppend = false;
                             break;
@@ -168,8 +199,7 @@ KDebugSettingsUtil::LineLoggingQtCategory KDebugSettingsUtil::parseLineLoggingQt
     LineLoggingQtCategory lineCategory;
     int equalPos = line.indexOf(QLatin1Char('='));
     if ((equalPos != -1)
-            && (line.lastIndexOf(QLatin1Char('=')) == equalPos)) {
-
+        && (line.lastIndexOf(QLatin1Char('=')) == equalPos)) {
         const QString pattern = line.left(equalPos);
         const QString valueStr = line.mid(equalPos + 1);
         if (valueStr == QLatin1String("true")) {
@@ -208,6 +238,7 @@ KDebugSettingsUtil::LineLoggingQtCategory KDebugSettingsUtil::parseLineLoggingQt
 QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQtCategories(const QString &filename)
 {
     if (filename.isEmpty()) {
+        qCWarning(KDEBUGSETTINGS_LOG) << "Empty file name";
         return {};
     }
     //Code based on src/corelib/io/qloggingregistry.cpp
@@ -297,6 +328,26 @@ QList<KDebugSettingsUtil::LoadLoggingCategory> KDebugSettingsUtil::readLoggingQt
                 }
             }
         }
+    } else {
+        qCWarning(KDEBUGSETTINGS_LOG) << "Impossible to open file: " << filename;
     }
+
     return hashLoadLoggingCategories.values();
 }
+
+LoggingCategory::LoggingType KDebugSettingsUtil::convertCategoryTypeFromString(const QString &str)
+{
+    if (str.isEmpty()) {
+        return LoggingCategory::Info; //Default
+    } else if (str == QLatin1String("DEBUG")) {
+         return LoggingCategory::Debug;
+    } else if (str == QLatin1String("INFO")) {
+        return LoggingCategory::Info;
+    } else if (str == QLatin1String("WARNING")) {
+        return LoggingCategory::Warning;
+    } else if (str == QLatin1String("CRITICAL")) {
+        return LoggingCategory::Critical;
+    }
+    qCWarning(KDEBUGSETTINGS_LOG) << "Default category is unknown: " << str;
+    return LoggingCategory::Info;
+}
